@@ -90,7 +90,7 @@ namespace BOOM {
         double total_prediction_sd,
         double prior_tree_depth_alpha,
         double prior_tree_depth_beta,
-        boost::function<double(int)> log_prior_on_number_of_trees,
+        std::function<double(int)> log_prior_on_number_of_trees,
         RNG &seeding_rng = GlobalRng::rng);
 
     void draw() override;
@@ -118,7 +118,7 @@ namespace BOOM {
     void impute_latent_data_point(DataType *data);
    private:
     ProbitBartModel *model_;
-    std::vector<boost::shared_ptr<DataType> > residuals_;
+    std::vector<std::shared_ptr<DataType> > residuals_;
   };
 
 }  // namespace BOOM
