@@ -25,7 +25,7 @@ namespace BOOM{
   class DoubleModel : virtual public MixtureComponent{
    public:
     virtual double logp(double x) const = 0;
-    virtual double sim() const = 0;
+    virtual double sim(RNG &rng = GlobalRng::rng) const = 0;
     DoubleModel *clone() const override = 0;
     virtual double pdf(Ptr<Data> dp, bool logscale) const;
     double pdf(const Data * dp, bool logscale) const override;
