@@ -256,11 +256,11 @@ namespace BOOM{
     virtual Vector predict(const Vector &x)const;
 
     //---- simulate MV regression data ---
-    virtual MvRegData * simdat()const;
-    virtual MvRegData * simdat(const Vector &X)const;
+    virtual MvRegData * simdat(RNG &rng = GlobalRng::rng)const;
+    virtual MvRegData * simdat(const Vector &X, RNG &rng = GlobalRng::rng)const;
 
     // no intercept
-    Vector simulate_fake_x()const;
+    Vector simulate_fake_x(RNG &rng = GlobalRng::rng)const;
   };
 }
 #endif // BOOM_MVREG_HPP
