@@ -24,6 +24,7 @@
 #include <Models/Policies/PriorPolicy.hpp>
 #include <Models/Glm/GlmCoefs.hpp>
 #include <Models/Glm/Glm.hpp>
+#include <Models/Hierarchical/HierarchicalZeroInflatedGammaModel.hpp>
 
 namespace BOOM {
 
@@ -75,6 +76,9 @@ namespace BOOM {
 
     double sim(const Vector &x, RNG &rng = BOOM::GlobalRng::rng) const;
 
+    HierarchicalZeroInflatedGammaData simulate_sufficient_statistics(
+        const Vector &x, int64_t n, RNG &rng = BOOM::GlobalRng::rng) const;
+
    private:
     double zero_threshold_;
   };
