@@ -82,7 +82,7 @@ namespace BOOM{
     const SpdMatrix & Sigma() const override;
     const SpdMatrix & siginv() const override;
     double ldsi() const override;
-    Vector sim() const override;
+    Vector sim(RNG &rng = GlobalRng::rng) const override;
 
     Ptr<VectorParams> Mu_prm();
     const Ptr<VectorParams> Mu_prm() const;
