@@ -38,6 +38,9 @@ namespace BOOM {
 
     double logp(double prior_mean, double prior_sample_size)const;
 
+    // Exposed for testing.
+    const PoissonGammaModel *model() const { return model_;}
+
    private:
     PoissonGammaModel *model_;
 
