@@ -19,7 +19,7 @@
 #define BOOM_SPD_STORAGE_HPP
 
 #include <Models/DataTypes.hpp>
-#include <boost/function.hpp>
+#include <functional>
 
 namespace BOOM{
   namespace SPD{
@@ -32,20 +32,23 @@ namespace BOOM{
     // watching it, so they know that their data needs to be updated.
     class Storage{
      public:
-      Storage(bool current=false);
+      // Args:
+      //   current: A flag indicating whether the data held by storage
+      //     is current
+      Storage(bool current = false);
       Storage(const Storage &rhs);
       virtual ~Storage();
-      virtual Storage * clone()const=0;
+      virtual Storage * clone() const = 0;
 
       // Returns the length of one side of the stored matrix.
-      virtual uint dim()const=0;
+      virtual uint dim() const = 0;
 
       // The storage capacity requirements of either the full matrix
       // (minimial = false), or the triangle (minimial = true).
-      virtual uint size(bool minimal=true)const;
+      virtual uint size(bool minimal = true) const;
 
       // Is the stored data current?
-      bool current()const;
+      bool current() const;
 
       // Signal any observers that a change has been made.
       void signal();
@@ -55,15 +58,16 @@ namespace BOOM{
 
       // Creates an observer that can be placed in another Storage
       // object using add_observer().
-      boost::function<void(void)> create_observer();
+      std::function<void(void)> create_observer();
 
       // Adds an from another Storage object.
-      void add_observer(boost::function<void(void)>);
+      void add_observer(std::function<void(void)>);
+
      private:
       bool current_;
       void observe_changes();
 
-      std::vector<boost::function<void(void)> >signals_;
+      std::vector<std::function<void(void)> >signals_;
     };
 
     //------------------------------------------------------------
@@ -73,15 +77,15 @@ namespace BOOM{
       CholStorage();
       CholStorage(const SpdMatrix &S);
       CholStorage(const CholStorage &rhs);
-      CholStorage * clone()const override;
-      uint dim()const override;
-      void set(const Matrix &L, bool sig=true);
+      CholStorage * clone() const override;
+      uint dim() const override;
+      void set(const Matrix &L, bool sig = true);
       void refresh(const SpdStorage &);
-      const Matrix & value()const;
+      const Matrix & value() const;
     private:
       Matrix L;
     };
-    typedef boost::shared_ptr<CholStorage> CholPtr;
+    typedef std::shared_ptr<CholStorage> CholPtr;
 
     //------------------------------------------------------------
     class SpdStorage : public Storage{
@@ -89,16 +93,16 @@ namespace BOOM{
       SpdStorage();
       SpdStorage(const SpdMatrix &S);
       SpdStorage(const SpdStorage &S);
-      SpdStorage * clone()const override;
-      uint dim()const override;
-      const SpdMatrix & value()const;
-      void set(const SpdMatrix &, bool sig=true);
-      void refresh_from_chol(const CholStorage&, bool inv=false);
+      SpdStorage * clone() const override;
+      uint dim() const override;
+      const SpdMatrix & value() const;
+      void set(const SpdMatrix &, bool sig = true);
+      void refresh_from_chol(const CholStorage&, bool inv = false);
       void refresh_from_inv(const SpdStorage &, CholStorage &);
     private:
       SpdMatrix sig_;
     };
-    typedef boost::shared_ptr<SpdStorage> SpdPtr;
+    typedef std::shared_ptr<SpdStorage> SpdPtr;
   }
   //____________________________________________________________
 
@@ -111,43 +115,46 @@ namespace BOOM{
     : public DataTraits<Spd>
   {
   public:
-    SpdData(uint n, double diag=1.0, bool ivar=false);
-    SpdData(const SpdMatrix &S, bool ivar=false);
+    SpdData(uint n, double diag=1.0, bool ivar = false);
+    SpdData(const SpdMatrix &S, bool ivar = false);
     SpdData(const SpdData &rhs);
-    SpdData * clone()const override;
+    SpdData * clone() const override;
 
-    virtual uint size(bool minimal=true)const;
-    virtual uint dim()const;
-    ostream & display(ostream &out)const override;
+    virtual uint size(bool minimal = true) const;
+    virtual uint dim() const;
+    ostream & display(ostream &out) const override;
 
-    const SpdMatrix & value()const override;
-    void set(const SpdMatrix &v, bool sig=true) override;
+    const SpdMatrix & value() const override;
+    void set(const SpdMatrix &v, bool sig = true) override;
 
-    const SpdMatrix & var()const;
-    const SpdMatrix & ivar()const;
-    const Matrix & var_chol()const;
-    const Matrix & ivar_chol()const;
-    double ldsi()const;
+    const SpdMatrix & var() const;
+    const SpdMatrix & ivar() const;
+    const Matrix & var_chol() const;
+    const Matrix & ivar_chol() const;
+    double ldsi() const;
 
-    void set_var(const SpdMatrix &, bool signal=true);
-    void set_ivar(const SpdMatrix &, bool signal=true);
-    void set_var_chol(const Matrix &L, bool signal=true);
-    void set_ivar_chol(const Matrix &L, bool signal=true);
+    void set_var(const SpdMatrix &, bool signal = true);
+    void set_ivar(const SpdMatrix &, bool signal = true);
+    void set_var_chol(const Matrix &L, bool signal = true);
+    void set_ivar_chol(const Matrix &L, bool signal = true);
 
     // Args:
     //   sd:  A vector of standard deviations to go along the diagonal.
     //   L:  The lower cholesky triangle for a correlation matrix.
     void set_S_Rchol(const Vector &sd, const Matrix &L);
 
-    void ensure_ivar_current()const;
-    void ensure_var_current()const;
-    void ensure_var_chol_current()const;
-    void ensure_ivar_chol_current()const;
+    // Check that the desired representation contains the desired
+    // data.  If not then find and refresh from the current
+    // representation.
+    void ensure_ivar_current() const;
+    void ensure_var_current() const;
+    void ensure_var_chol_current() const;
+    void ensure_ivar_chol_current() const;
 
   private:
-    typedef boost::shared_ptr<SPD::SpdStorage>  SpdPtr;
-    typedef boost::shared_ptr<SPD::CholStorage> CholPtr;
-    typedef boost::shared_ptr<SPD::Storage> StoragePtr;
+    typedef std::shared_ptr<SPD::SpdStorage>  SpdPtr;
+    typedef std::shared_ptr<SPD::CholStorage> CholPtr;
+    typedef std::shared_ptr<SPD::Storage> StoragePtr;
 
     mutable SpdPtr var_;
     mutable SpdPtr ivar_;
@@ -160,8 +167,7 @@ namespace BOOM{
 
     // Create observers among all the available storage modes.
     void setup_storage();
-    void ensure_current(SpdPtr, CholPtr, SpdPtr, CholPtr)const;
-    void ensure_chol_current(CholPtr, SpdPtr, CholPtr, SpdPtr)const;
+
   };
-}
+}  // namespace BOOM
 #endif// BOOM_SPD_STORAGE_HPP
