@@ -71,7 +71,7 @@ namespace BOOM{
         const ConstVectorView &error_mean,
         const ConstSubMatrix &error_variance) override;
 
-    void simulate_state_error(VectorView eta, int t) const override;
+    void simulate_state_error(RNG &rng, VectorView eta, int t) const override;
 
     Ptr<SparseMatrixBlock> state_transition_matrix(int t) const override;
     Ptr<SparseMatrixBlock> state_variance_matrix(int t) const override;
