@@ -68,7 +68,7 @@ namespace BOOM {
     uint state_error_dimension() const override {
       return 1;
     }
-    void simulate_state_error(VectorView eta, int t) const override;
+    void simulate_state_error(RNG &rng, VectorView eta, int t) const override;
 
     Ptr<SparseMatrixBlock> state_transition_matrix(int t) const override;
     Ptr<SparseMatrixBlock> state_variance_matrix(int t) const override;
