@@ -133,7 +133,7 @@ namespace BOOM {
       double total_prediction_sd,
       double prior_tree_depth_alpha,
       double prior_tree_depth_beta,
-      boost::function<double(int)> log_prior_on_number_of_trees,
+      std::function<double(int)> log_prior_on_number_of_trees,
       RNG &seeding_rng)
       : BartPosteriorSamplerBase(model,
                                  total_prediction_sd,
@@ -225,7 +225,7 @@ namespace BOOM {
   PoissonBartPosteriorSampler::create_and_store_residual(int i) {
     Ptr<PoissonRegressionData> dp = model_->dat()[i];
     double initial_prediction = model_->predict(dp->x());
-    boost::shared_ptr<Bart::PoissonResidualRegressionData> data(
+    std::shared_ptr<Bart::PoissonResidualRegressionData> data(
         new Bart::PoissonResidualRegressionData(dp, initial_prediction));
     residuals_.push_back(data);
     return data.get();
