@@ -25,7 +25,7 @@
 #include <Models/Glm/PosteriorSamplers/BregVsSampler.hpp>
 #include <Models/MvnGivenScalarSigma.hpp>
 
-namespace BOOM{
+namespace BOOM {
 
   typedef BregVsSampler BVS;
 
@@ -38,7 +38,7 @@ namespace BOOM{
       double sigma_guess = sqrt(sample_variance * (1-expected_rsq));
       return new ChisqModel(prior_nobs, sigma_guess);
     }
-  }
+  }  // namespace
 
   //----------------------------------------------------------------------
   BVS::BregVsSampler(RegressionModel * mod,
@@ -48,37 +48,37 @@ namespace BOOM{
                      bool first_term_is_intercept,
                      RNG &seeding_rng)
     : PosteriorSampler(seeding_rng),
-      m_(mod),
+      model_(mod),
       spri_(create_siginv_prior(mod, prior_nobs, expected_rsq)),
-      indx(seq<uint>(0, m_->nvars_possible()-1)),
+      indx(seq<uint>(0, model_->nvars_possible()-1)),
       max_nflips_(indx.size()),
       draw_beta_(true),
       draw_sigma_(true),
       // Initialize mutable workspace variables to illegal values.
-      beta_tilde_(1, negative_infinity()),
-      iV_tilde_(1, negative_infinity()),
+      posterior_mean_(1, negative_infinity()),
+      unscaled_posterior_precision_(1, negative_infinity()),
       DF_(negative_infinity()),
       SS_(negative_infinity()),
       sigsq_sampler_(spri_)
   {
-    uint p = m_->nvars_possible();
+    uint p = model_->nvars_possible();
     Vector b = Vector(p, 0.0);
     if (first_term_is_intercept) {
-      b[0] = m_->suf()->ybar();
+      b[0] = model_->suf()->ybar();
     }
-    SpdMatrix ominv(m_->suf()->xtx());
-    double n = m_->suf()->n();
+    SpdMatrix ominv(model_->suf()->xtx());
+    double n = model_->suf()->n();
     ominv *= prior_nobs / n;
-    bpri_ = new MvnGivenScalarSigma(ominv, mod->Sigsq_prm());
+    slab_ = new MvnGivenScalarSigma(ominv, mod->Sigsq_prm());
 
     double prob = expected_model_size/p;
-    if (prob>1) prob = 1.0;
+    if (prob > 1) prob = 1.0;
     Vector pi(p, prob);
     if (first_term_is_intercept) {
       pi[0] = 1.0;
     }
 
-    vpri_ = new VariableSelectionPrior(pi);
+    spike_ = new VariableSelectionPrior(pi);
     check_dimensions();
   }
   //----------------------------------------------------------------------
@@ -91,20 +91,20 @@ namespace BOOM{
                      bool force_intercept,
                      RNG &seeding_rng)
     : PosteriorSampler(seeding_rng),
-      m_(mod),
+      model_(mod),
       spri_(new ChisqModel(prior_sigma_nobs, prior_sigma_guess)),
-      indx(seq<uint>(0, m_->nvars_possible()-1)),
+      indx(seq<uint>(0, model_->nvars_possible()-1)),
       max_nflips_(indx.size()),
       draw_beta_(true),
       draw_sigma_(true),
       sigsq_sampler_(spri_)
   {
-    uint p = m_->nvars_possible();
+    uint p = model_->nvars_possible();
     Vector b = Vector(p, 0.0);
     double ybar = mod->suf()->ybar();
     b[0] = ybar;
-    SpdMatrix ominv(m_->suf()->xtx());
-    double n = m_->suf()->n();
+    SpdMatrix ominv(model_->suf()->xtx());
+    double n = model_->suf()->n();
 
     if (prior_sigma_guess <= 0) {
       ostringstream msg;
@@ -130,16 +130,16 @@ namespace BOOM{
     if (alpha < 1.0) {
       diag(ominv).axpy(diag(ominv), alpha/(1-alpha));
       ominv *= (1-alpha);
-    }else{
+    } else {
       ominv.set_diag(diag(ominv));
     }
 
-    bpri_ = new MvnGivenScalarSigma(b, ominv, m_->Sigsq_prm());
+    slab_ = new MvnGivenScalarSigma(b, ominv, model_->Sigsq_prm());
 
     Vector pi(p, prior_inclusion_probability);
     if (force_intercept) pi[0] = 1.0;
 
-    vpri_ = new VariableSelectionPrior(pi);
+    spike_ = new VariableSelectionPrior(pi);
     check_dimensions();
   }
   //----------------------------------------------------------------------
@@ -151,11 +151,11 @@ namespace BOOM{
                      const Vector &prior_inclusion_probs,
                      RNG &seeding_rng)
     : PosteriorSampler(seeding_rng),
-      m_(mod),
-      bpri_(new MvnGivenScalarSigma(b, Omega_inverse, m_->Sigsq_prm())),
+      model_(mod),
+      slab_(new MvnGivenScalarSigma(b, Omega_inverse, model_->Sigsq_prm())),
       spri_(new ChisqModel(df, sigma_guess)),
-      vpri_(new VariableSelectionPrior(prior_inclusion_probs)),
-      indx(seq<uint>(0, m_->nvars_possible()-1)),
+      spike_(new VariableSelectionPrior(prior_inclusion_probs)),
+      indx(seq<uint>(0, model_->nvars_possible()-1)),
       max_nflips_(indx.size()),
       draw_beta_(true),
       draw_sigma_(true),
@@ -168,15 +168,15 @@ namespace BOOM{
                      const ZellnerPriorParameters &prior,
                      RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
-        m_(model),
-        bpri_(new MvnGivenScalarSigma(
+        model_(model),
+        slab_(new MvnGivenScalarSigma(
             prior.prior_beta_guess,
             prior.prior_beta_information,
-            m_->Sigsq_prm())),
+            model_->Sigsq_prm())),
         spri_(new ChisqModel(prior.prior_sigma_guess_weight,
                              prior.prior_sigma_guess)),
-        vpri_(new VariableSelectionPrior(prior.prior_inclusion_probabilities)),
-        indx(seq<uint>(0, m_->nvars_possible()-1)),
+        spike_(new VariableSelectionPrior(prior.prior_inclusion_probabilities)),
+        indx(seq<uint>(0, model_->nvars_possible()-1)),
         max_nflips_(indx.size()),
         draw_beta_(true),
         draw_sigma_(true),
@@ -191,11 +191,11 @@ namespace BOOM{
                      Ptr<VariableSelectionPrior> vpri,
                      RNG &seeding_rng)
     : PosteriorSampler(seeding_rng),
-      m_(mod),
-      bpri_(bpri),
+      model_(mod),
+      slab_(bpri),
       spri_(spri),
-      vpri_(vpri),
-      indx(seq<uint>(0, m_->nvars_possible()-1)),
+      spike_(vpri),
+      indx(seq<uint>(0, model_->nvars_possible()-1)),
       max_nflips_(indx.size()),
       draw_beta_(true),
       draw_sigma_(true),
@@ -204,13 +204,15 @@ namespace BOOM{
     check_dimensions();
   }
   //----------------------------------------------------------------------
-  void BVS::limit_model_selection(uint n) { max_nflips_ =n;}
+  void BVS::limit_model_selection(uint n) { max_nflips_ = n;}
   void BVS::allow_model_selection(bool allow) {
     if (allow) {
       max_nflips_ = indx.size();
-    } else suppress_model_selection();
+    } else {
+      suppress_model_selection();
+    }
   }
-  void BVS::suppress_model_selection() {max_nflips_ =0;}
+  void BVS::suppress_model_selection() {max_nflips_ = 0;}
   void BVS::suppress_beta_draw() {draw_beta_ = false;}
   void BVS::allow_beta_draw() {draw_beta_ = false;}
   void BVS::suppress_sigma_draw() {draw_sigma_ = false;}
@@ -221,18 +223,18 @@ namespace BOOM{
   double BVS::prior_ss() const { return 2 * spri_->beta(); }
 
   double BVS::log_model_prob(const Selector &g) const {
-    if (g.nvars()==0) {
+    if (g.nvars() == 0) {
       // Integrate out sigma.  The empty model is handled as a special
       // case because information matrices cancel, and do not appear
       // in the sum of squares.  It is easier to handle them here than
       // to impose a global requirement about what logdet() should
       // mean for an empty matrix.
-      double ss = m_->suf()->yty() + prior_ss();
-      double df = m_->suf()->n() + prior_df();
-      double ans = vpri_->logp(g) - (.5*df-1)*log(ss);
+      double ss = model_->suf()->yty() + prior_ss();
+      double df = model_->suf()->n() + prior_df();
+      double ans = spike_->logp(g) - (.5*df-1)*log(ss);
       return ans;
     }
-    double ans = vpri_->logp(g);
+    double ans = spike_->logp(g);
     if (ans == negative_infinity()) {
       return ans;
     }
@@ -240,7 +242,7 @@ namespace BOOM{
     if (ldoi <= negative_infinity()) {
       return negative_infinity();
     }
-    ans += .5*(ldoi - iV_tilde_.logdet());
+    ans += .5*(ldoi - unscaled_posterior_precision_.logdet());
     ans -= (.5*DF_-1)*log(SS_);
     return ans;
   }
@@ -248,7 +250,7 @@ namespace BOOM{
   double BVS::mcmc_one_flip(Selector &mod, uint which_var, double logp_old) {
     mod.flip(which_var);
     double logp_new = log_model_prob(mod);
-    double u = runif (0,1);
+    double u = runif_mt(rng(), 0, 1);
     if (log(u) > logp_new - logp_old) {
       mod.flip(which_var);  // reject draw
       return logp_old;
@@ -257,16 +259,16 @@ namespace BOOM{
   }
   //----------------------------------------------------------------------
   void BVS::draw() {
-    if (max_nflips_>0) draw_model_indicators();
+    if (max_nflips_ > 0) draw_model_indicators();
     if (draw_beta_ || draw_sigma_) {
-      set_reg_post_params(m_->coef().inc(),false);
+      set_reg_post_params(model_->coef().inc(), false);
     }
     if (draw_sigma_) draw_sigma();
     if (draw_beta_) draw_beta();
   }
   //----------------------------------------------------------------------
   bool BVS::model_is_empty() const {
-    return m_->coef().inc().nvars()==0;
+    return model_->coef().inc().nvars() == 0;
   }
   //----------------------------------------------------------------------
   void BVS::set_sigma_upper_limit(double sigma_upper_limit) {
@@ -274,120 +276,131 @@ namespace BOOM{
   }
 
   void BVS::find_posterior_mode(double) {
-    set_reg_post_params(m_->coef().inc(), true);
-    m_->set_included_coefficients(beta_tilde_);
-    m_->set_sigsq(SS_ / DF_);
+    set_reg_post_params(model_->coef().inc(), true);
+    model_->set_included_coefficients(posterior_mean_);
+    model_->set_sigsq(SS_ / DF_);
   }
 
   //----------------------------------------------------------------------
   void BVS::draw_sigma() {
     double df, ss;
     if (model_is_empty()) {
-      ss = m_->suf()->yty();
-      df = m_->suf()->n();
+      ss = model_->suf()->yty();
+      df = model_->suf()->n();
     } else {
       df = DF_ - prior_df();
       ss = SS_ - prior_ss();
     }
     double sigsq = draw_sigsq_given_sufficient_statistics(df, ss);
-    m_->set_sigsq(sigsq);
+    model_->set_sigsq(sigsq);
   }
   //----------------------------------------------------------------------
   void BVS::draw_beta() {
     if (model_is_empty()) return;
-    iV_tilde_ /= m_->sigsq();
-    beta_tilde_ = rmvn_ivar(beta_tilde_, iV_tilde_);
-    m_->set_included_coefficients(beta_tilde_);
+    posterior_mean_ = rmvn_ivar_mt(
+        rng(), posterior_mean_, unscaled_posterior_precision_ / model_->sigsq());
+    model_->set_included_coefficients(posterior_mean_);
   }
   //----------------------------------------------------------------------
   void BVS::draw_model_indicators() {
-    Selector g = m_->coef().inc();
+    Selector g = model_->coef().inc();
     std::random_shuffle(indx.begin(), indx.end());
     double logp = log_model_prob(g);
 
+    if (!std::isfinite(logp)) {
+      spike_->make_valid(g);
+      logp = log_model_prob(g);
+    }
     if (!std::isfinite(logp)) {
       ostringstream err;
       err << "BregVsSampler did not start with a legal configuration." << endl
           << "Selector vector:  " << g << endl
-          << "beta: " << m_->included_coefficients() << endl;
+          << "beta: " << model_->included_coefficients() << endl;
       report_error(err.str());
     }
 
     uint n = std::min<uint>(max_nflips_, g.nvars_possible());
-    for (uint i=0; i<n; ++i) {
+    for (uint i = 0; i < n; ++i) {
       logp = mcmc_one_flip(g, indx[i], logp);
     }
-    m_->coef().set_inc(g);
+    model_->coef().set_inc(g);
   }
   //----------------------------------------------------------------------
   double BVS::logpri() const {
-    const Selector &g(m_->coef().inc());
-    double ans = vpri_->logp(g);  // p(gamma)
+    const Selector &g(model_->coef().inc());
+    double ans = spike_->logp(g);  // p(gamma)
     if (ans <= BOOM::negative_infinity()) return ans;
 
-    double sigsq = m_->sigsq();
+    double sigsq = model_->sigsq();
     ans += sigsq_sampler_.log_prior(sigsq);
 
     if (g.nvars() > 0) {
-      ans += dmvn(g.select(m_->Beta()),
-                  g.select(bpri_->mu()),
-                  g.select(bpri_->siginv()), true);
+      ans += dmvn(g.select(model_->Beta()),
+                  g.select(slab_->mu()),
+                  g.select(slab_->siginv()), true);
     }
     return ans;
   }
   //----------------------------------------------------------------------
-  double BVS::set_reg_post_params(const Selector &g, bool do_ldoi) const {
-    if (g.nvars()==0) {
+  double BVS::set_reg_post_params(const Selector &inclusion_indicators,
+                                  bool do_ldoi) const {
+    if (inclusion_indicators.nvars() == 0) {
       return 0;
     }
-    Vector b = g.select(bpri_->mu());
+    Vector prior_mean = inclusion_indicators.select(slab_->mu());
     // Sigma = sigsq * Omega, so
     // siginv = ominv / sigsq, so
     // ominv = siginv * sigsq.
-    SpdMatrix Ominv = g.select(bpri_->siginv()) * m_->sigsq();
-    double ldoi = do_ldoi ? Ominv.logdet() : 0.0;
+    SpdMatrix unscaled_prior_precision =
+        inclusion_indicators.select(slab_->siginv()) * model_->sigsq();
+    double ldoi = do_ldoi ? unscaled_prior_precision.logdet() : 0.0;
 
-    Ptr<RegSuf> s = m_->suf();
+    Ptr<RegSuf> s = model_->suf();
 
-    SpdMatrix xtx = s->xtx(g);
-    Vector xty = s->xty(g);
+    SpdMatrix xtx = s->xtx(inclusion_indicators);
+    Vector xty = s->xty(inclusion_indicators);
 
-    // iV_tilde_ / sigsq is the inverse of the posterior precision
-    // matrix, given g.
-    iV_tilde_ = Ominv + xtx;
-    // beta_tilde_ is the posterior mean, given g
-    beta_tilde_ = Ominv * b + xty;
+    // unscaled_posterior_precision_ / sigsq is the conditional posterior
+    // precision matrix, given inclusion_indicators.
+    unscaled_posterior_precision_ = unscaled_prior_precision + xtx;
+    // posterior_mean_ is the posterior mean, given inclusion_indicators.
+    posterior_mean_ = unscaled_prior_precision * prior_mean + xty;
     bool positive_definite = true;
-    beta_tilde_ = iV_tilde_.solve(beta_tilde_, positive_definite);
+    posterior_mean_ = unscaled_posterior_precision_.solve(
+        posterior_mean_, positive_definite);
     if (!positive_definite) {
-      beta_tilde_ = Vector(iV_tilde_.nrow());
+      posterior_mean_ = Vector(unscaled_posterior_precision_.nrow());
       return negative_infinity();
     }
     DF_ = s->n() + prior_df();
+    // SS_ starts off with the prior sum of squares from the prior on sigma^2.
     SS_ = prior_ss();
 
-    // Add in the sum of squared errors around beta_tilde_
-    double likelihood_ss = s->yty() - 2*beta_tilde_.dot(xty)
-        + xtx.Mdist(beta_tilde_);
+    // Add in the sum of squared errors around posterior_mean_
+    double likelihood_ss = s->yty() - 2 * posterior_mean_.dot(xty)
+        + xtx.Mdist(posterior_mean_);
     SS_ +=likelihood_ss;
 
-    // Add in the sum of squares from the prior
-    double prior_ss = Ominv.Mdist(beta_tilde_, b);
-    SS_ += prior_ss;
-
+    // Add in the sum of squares component arising from the discrepancy between
+    // the prior and posterior means.
+    SS_ += unscaled_prior_precision.Mdist(posterior_mean_, prior_mean);
+    if (SS_ < 0) {
+      report_error("Illegal data caused negative sum of squares "
+                   "in Breg::set_reg_post_params.");
+    }
     return ldoi;
   }
 
   void BVS::check_dimensions() const {
-    if (vpri_->potential_nvars() != bpri_->dim()) {
+    if (spike_->potential_nvars() != slab_->dim()) {
       ostringstream err;
       err << "Objects of incompatible dimension were passed to the "
           << "BregVsSampler constructor." << endl
           << "The prior on the set of coefficients had dimension "
-          << bpri_->dim()
+          << slab_->dim()
           << ", while the prior on the set of inclusion indicators "
           << "had dimension "
-          << vpri_->potential_nvars() << "."  << endl;
+          << spike_->potential_nvars() << "."  << endl;
       report_error(err.str());
     }
   }
