@@ -61,16 +61,18 @@ namespace BOOM {
       Ptr<AugmentedData> dp = data[t];
       double state_contribution = model_->observation_matrix(t).dot(
           model_->state(t));
-      for (int j = 0; j < dp->sample_size(); ++j) {
+      for (int j = 0; j < dp->total_sample_size(); ++j) {
         const RegressionData &observation(dp->regression_data(j));
-        double regression_contribution =
-            model_->observation_model()->predict(observation.x());
-        double weight = data_imputer_.impute(
-            rng(),
-            observation.y() - regression_contribution - state_contribution,
-            model_->observation_model()->sigma(),
-            model_->observation_model()->nu());
-        dp->set_weight(weight, j);
+        if (observation.missing() == Data::observed) {
+          double regression_contribution =
+              model_->observation_model()->predict(observation.x());
+          double weight = data_imputer_.impute(
+              rng(),
+              observation.y() - regression_contribution - state_contribution,
+              model_->observation_model()->sigma(),
+              model_->observation_model()->nu());
+          dp->set_weight(weight, j);
+        }
       }
     }
   }
@@ -83,13 +85,14 @@ namespace BOOM {
     // sufficient statistics, but the tail thickness parameter is drawn
     // conditional on the other parameters using a likelihood evaluation that
     // requires a loop over the data.
-    if (model_->observation_model()->dat().size() != model_->sample_size()) {
+    if (model_->observation_model()->dat().size() !=
+        model_->total_sample_size()) {
       model_->observation_model()->clear_data();
       subordinate_data_.clear();
       for (int i = 0; i < model_->time_dimension(); ++i) {
         std::vector<Ptr<RegressionData>> local_subordinate_data;
         Ptr<AugmentedData> real_data_point = model_->dat()[i];
-        int local_sample_size = real_data_point->sample_size();
+        int local_sample_size = real_data_point->total_sample_size();
         for (int j = 0; j < local_sample_size; ++j) {
           const RegressionData &real_observation(
               real_data_point->regression_data(j));
@@ -97,7 +100,9 @@ namespace BOOM {
               new DoubleData(real_observation.y()),
               real_observation.Xptr());
           local_subordinate_data.push_back(subordinate_data);
-          model_->observation_model()->add_data(subordinate_data);
+          if (real_observation.missing() == Data::observed) {
+            model_->observation_model()->add_data(subordinate_data);
+          }
         }
         subordinate_data_.push_back(local_subordinate_data);
       }
@@ -106,14 +111,17 @@ namespace BOOM {
 
   void SSSPS::update_complete_data_sufficient_statistics(int t) {
     Ptr<AugmentedData> dp = model_->dat()[t];
-    for (int i = 0; i < dp->sample_size(); ++i) {
+    for (int i = 0; i < dp->total_sample_size(); ++i) {
       const RegressionData &observation(dp->regression_data(i));
-      double time_series_residual = observation.y() - dp->state_model_offset();
-      observation_model_sampler_->update_complete_data_sufficient_statistics(
-          time_series_residual,
-          observation.x(),
-          dp->weight(i));
-      subordinate_data_[t][i]->set_y(time_series_residual);
+      if (observation.missing() == Data::observed) {
+        double time_series_residual =
+            observation.y() - dp->state_model_offset();
+        observation_model_sampler_->update_complete_data_sufficient_statistics(
+            time_series_residual,
+            observation.x(),
+            dp->weight(i));
+        subordinate_data_[t][i]->set_y(time_series_residual);
+      }
     }
   }
 
